@@ -493,7 +493,7 @@ set_proxy (SoupSession *session)
 		proxy_uri = g_strdup_printf ("http://%s:%d", host, port);
 
 	uri = soup_uri_new (proxy_uri);
-	g_object_set (G_OBJECT (session), "proxy-uri", uri);
+	g_object_set (G_OBJECT (session), "proxy-uri", uri, NULL);
 	
 	g_free (host);
 	g_free (username);
@@ -504,6 +504,40 @@ set_proxy (SoupSession *session)
 
 }
 
+
+static char*
+create_report_title (BugzillaApplication *app, int type, const char *description)
+{
+	char *title;
+	int limit;
+	long size;
+	char *tmp = NULL;
+
+	if (description) {
+		tmp = g_malloc0 (256); /* This should be safe enough for 24 UTF-8 chars.
+					* anyway, I miss a g_utf8_strndup :) */ 
+		size = g_utf8_strlen (description, -1);
+		if (size > 24) {
+			g_utf8_strncpy (tmp, description, 24);
+		} else {
+			g_utf8_strncpy (tmp, description, size);
+		}
+	}
+
+	if (type == BUG_TYPE_CRASH) {
+		title = g_strdup_printf ("crash in %s: %s%s", app->cname, 
+				         tmp ? tmp : "empty description",
+					 (tmp && size > 24) ? "..." : "");
+	} else {
+		title = g_strdup_printf ("%s: %s%s", app->cname,
+					 tmp ? tmp : "empty description",
+			       		 (tmp && size > 24) ? "..." : "");
+	}
+
+	g_free (tmp);
+
+	return title;
+}
 static void
 send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML *xml)
 {
@@ -511,8 +545,10 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML
 	GtkTextBuffer *buffer;
 	GtkTextIter start;
 	GtkTextIter end;
+	int type;
 	char *gdb_text;
 	char *details_text;
+	char *title;
 	char *final_text;
 	const char *email;
 	SoupSession *session;
@@ -539,8 +575,10 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML
 				      gdb_text != NULL ? gdb_text : "<empty backtrace>");
 	
 	email = gtk_entry_get_text (GTK_ENTRY (glade_xml_get_widget (xml, "email-entry")));
+	type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT(xml), "type"));
+	title = create_report_title (app, type, details_text);
 
-	message = bugzilla_create_report (app, gnome_version, email, final_text, xml, &err);
+	message = bugzilla_create_report (app, gnome_version, email, title, final_text, xml, &err);
 	if (message == NULL) {
 		char *text;
 
@@ -554,6 +592,7 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML
 		g_free (text);
 		g_free (gdb_text);
 		g_free (details_text);
+		g_free (title);
 		g_free (final_text);
 		gtk_main_quit();
 		return;
@@ -572,7 +611,6 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML
 		dir = g_dir_open (dirname, 0, &error);
 		if (dir) {
 			const char *name = g_dir_read_name (dir);
-			g_print ("There are pending reports!\n");
 			while (name != NULL) {
 				char *path;
 				char *contents;
@@ -581,7 +619,7 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML
 				if (g_file_get_contents (path, &contents, NULL, NULL)) {
 					SoupXmlrpcMessage *msg;
 					msg = soup_xmlrpc_message_new ("http://bugzilla.gnome.org/bugbuddy.cgi");
-					hacked_soup_xmlrpc_message_from_string (msg, contents);
+					soup_xmlrpc_message_from_string (msg, contents);
 					bug_count++;
 					soup_xmlrpc_message_persist (msg);
         				soup_session_queue_message (session, SOUP_MESSAGE (msg),
@@ -601,9 +639,9 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GladeXML
 	soup_xmlrpc_message_persist (message);
         soup_session_queue_message (session, SOUP_MESSAGE (message),
                                     (SoupMessageCallbackFn)bug_sent, xml);
-
 	g_free (gdb_text);
 	g_free (details_text);
+	g_free (title);
 	g_free (final_text);
 
 	gtk_statusbar_push (GTK_STATUSBAR (glade_xml_get_widget (xml, "statusbar")),
@@ -777,6 +815,8 @@ known_app_finished (GladeXML *xml)
 		gtk_entry_set_text (GTK_ENTRY (email_entry), default_email);
 		g_free (default_email);
 	}
+
+	gtk_widget_grab_focus (glade_xml_get_widget (xml, "details-view"));
 }
 
 static void
@@ -869,6 +909,8 @@ unknown_app_finished (GladeXML *xml)
 	                      "bug report can not be sent to the GNOME Bugzilla.  Please save the "
 	                      "bug to a text file and report it to the appropriate bug tracker "
 	                      "for this application."));
+
+	gtk_widget_grab_focus (glade_xml_get_widget (xml, "details-view"));
 }
 
 static void
@@ -1095,6 +1137,8 @@ main (int argc, char *argv[])
 	
 	g_object_set_data (G_OBJECT (xml), "gnome-version", gnome_version);
 
+	gtk_widget_show (main_window);
+
 	apps = load_applications ();
 	
 	/* If we have a binary file it is a crash */
@@ -1150,12 +1194,17 @@ main (int argc, char *argv[])
 				known_app_finished (xml);
 			}
 		}
+		g_object_set_data (G_OBJECT (xml), "type", GINT_TO_POINTER(BUG_TYPE_CRASH));
 	} else {
 		/* No binary file, so this is a non-crashing bug. Look the application from the --package arg */
 		GtkWidget *email_entry;
 		char *default_email;
 		
 		app = g_hash_table_find (apps, bugzilla_search_for_package, gopt_data.package);
+		if (app == NULL) {
+			/* Fallback to binary name */
+			app = g_hash_table_lookup (apps, gopt_data.package);
+		}
 		if (app == NULL) {
 			buddy_error (NULL, _("Bug Buddy doesn't know how to send a suggestion for the application %s.\n"),
 		                     	     gopt_data.package);
@@ -1204,7 +1253,7 @@ main (int argc, char *argv[])
 			gtk_entry_set_text (GTK_ENTRY (email_entry), default_email);
 			g_free (default_email);
 		}
-		g_free (s);
+		g_object_set_data (G_OBJECT (xml), "type", GINT_TO_POINTER(BUG_TYPE_REQUEST));
 	}
 	
 	if (gopt_data.include_file != NULL) {
@@ -1215,8 +1264,6 @@ main (int argc, char *argv[])
 	g_signal_connect (glade_xml_get_widget (xml, "close-button"), "clicked", 
 	                  G_CALLBACK (close_callback), xml);
 	
-	gtk_widget_show (main_window);
-
 	gtk_main ();
 
 	g_object_unref (program);
